@@ -23,4 +23,16 @@ where
             Self::Normal(t) => t,
         }
     }
+    /// Check if this field has not been set
+    pub fn is_default(&self) -> bool {
+        matches!(self, Self::Initial)
+    }
+    /// Check if this field has been set to none
+    pub fn is_none(&self) -> bool {
+        matches!(self, Self::Unset)
+    }
+    /// Check if this field has been set to some value
+    pub fn is_some(&self) -> bool {
+        matches!(self, Self::Normal(_))
+    }
 }
